==> ViennaCL-1.6.1.tar.gz: ViennaCL-1.6.1/doc/html/opencl_2matrix__operations_8hpp.js <==
var opencl_2matrix__operations_8hpp =
[
    [ "VIENNACL_SECTION_SIZE", "opencl_2matrix__operations_8hpp.html#a896e84eed510eabefb25c2dc08bffef4", null ],
    [ "am", "opencl_2matrix__operations_8hpp.html#a9b46aa01fc67f7d7fbc95056a1f050c6", null ],
    [ "ambm", "opencl_2matrix__operations_8hpp.html#a7e146ec12db4a4ec440d6ca9b8e46b79", null ],
    [ "ambm_m", "opencl_2matrix__operations_8hpp.html#a9af548eaf628c556dcd90938a2e11528", null ],
    [ "bidiag_pack", "opencl_2matrix__operations_8hpp.html#a37fbfb949aae5a860d0308717e5b4ff5", null ],
    [ "bidiag_pack_svd", "opencl_2matrix__operations_8hpp.html#ae9e45a4202d75a28076b78d133ba9379", null ],
    [ "copy_vec", "opencl_2matrix__operations_8hpp.html#a5d5b4fe8827c4d4da9f2df19cf8ee971", null ],
    [ "element_op", "opencl_2matrix__operations_8hpp.html#ab4be1fe81c4ca79108c4db2d7b23ec2c", null ],
    [ "element_op", "opencl_2matrix__operations_8hpp.html#af9c69aabdf179456bdf212e4b34e8b9a", null ],
    [ "exclusive_scan", "opencl_2matrix__operations_8hpp.html#a66235632539f84b9a5da2df6da5b573d", null ],
    [ "givens_next", "opencl_2matrix__operations_8hpp.html#aceca2a25a53f4b5c0dd836c8d024b170", null ],
    [ "house_update_A_left", "opencl_2matrix__operations_8hpp.html#a42d8cc5fddc8d8fe7819428f3570d8d7", null ],
    [ "house_update_A_right", "opencl_2matrix__operations_8hpp.html#aa37f02ed2a2f38dfea3abbfdeb5aab95", null ],
    [ "house_update_QL", "opencl_2matrix__operations_8hpp.html#a786d68766ad5e6b6fb239274efde0bf7", null ],
    [ "inclusive_scan", "opencl_2matrix__operations_8hpp.html#ac04e7aa6506170485722039430d329ab", null ],
    [ "matrix_assign", "opencl_2matrix__operations_8hpp.html#a23eccb767cb852d60170403a671dd91b", null ],
    [ "matrix_column", "opencl_2matrix__operations_8hpp.html#a6860ecc724d3ef7a1ba363c379357abf", null ],
    [ "matrix_diag_from_vector", "opencl_2matrix__operations_8hpp.html#af22fcf715396698796b26f45bece179e", null ],
    [ "matrix_diag_to_vector", "opencl_2matrix__operations_8hpp.html#affe958b9b7dc9ad1986e2b2b2cdb757a", null ],
    [ "matrix_diagonal_assign", "opencl_2matrix__operations_8hpp.html#ab334de39e0a14eec29eef532cf625be9", null ],
    [ "matrix_row", "opencl_2matrix__operations_8hpp.html#ae3f1e3bfcb56428f4e73e030ebae7066", null ],
    [ "prod_impl", "opencl_2matrix__operations_8hpp.html#ac368f3b6c47973062b06a7b765ca4521", null ],
    [ "prod_impl", "opencl_2matrix__operations_8hpp.html#a16366a34aab924b279bcd2b4f403a159", null ],
    [ "scaled_rank_1_update", "opencl_2matrix__operations_8hpp.html#aa1db022508f1ca9f0a42269205ac2565", null ],
    [ "trans", "opencl_2matrix__operations_8hpp.html#a72bf0d80c0608b5645d06703c7807253", null ],
    [ "SVD_BIDIAG_PACK_KERNEL", "opencl_2matrix__operations_8hpp.html#a6c692160febc1bf0c8c1b3f14609843b", null ],
    [ "SVD_COPY_COL_KERNEL", "opencl_2matrix__operations_8hpp.html#a83f95bb0dba31593bfdea7d48825ef45", null ],
    [ "SVD_COPY_ROW_KERNEL", "opencl_2matrix__operations_8hpp.html#adf9d9e0232c7731006e942e6f1eb787c", null ],
    [ "SVD_EXCLUSIVE_SCAN_KERNEL_1", "opencl_2matrix__operations_8hpp.html#a55efe16c86efff4d42bfa7ecea29fa70", null ],
    [ "SVD_GIVENS_NEXT_KERNEL", "opencl_2matrix__operations_8hpp.html#ae14982b121ba058e0cc0569b93f80646", null ],
    [ "SVD_HOUSEHOLDER_UPDATE_A_LEFT_KERNEL", "opencl_2matrix__operations_8hpp.html#a86b4bd11f0b1f0b701afa9448cbb865f", null ],
    [ "SVD_HOUSEHOLDER_UPDATE_A_RIGHT_KERNEL", "opencl_2matrix__operations_8hpp.html#a24049445243113b8aff433e4dd6d3c01", null ],
    [ "SVD_HOUSEHOLDER_UPDATE_QL_KERNEL", "opencl_2matrix__operations_8hpp.html#a656519064a982e5904b5a66b5e9c2785", null ],
    [ "SVD_INCLUSIVE_SCAN_KERNEL_1", "opencl_2matrix__operations_8hpp.html#a0c1e78c33de1edf10a666c2a3d561af3", null ],
    [ "SVD_SCAN_KERNEL_2", "opencl_2matrix__operations_8hpp.html#a5077728cfc9a2f2bdf1e480948a3fe6f", null ],
    [ "SVD_SCAN_KERNEL_3", "opencl_2matrix__operations_8hpp.html#ac35599cd7a904c6187e3d1e4c5b2d38b", null ],
    [ "SVD_SCAN_KERNEL_4", "opencl_2matrix__operations_8hpp.html#a24d101c5571414986506c8170ce4f261", null ]
];

==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/opencl_2matrix__operations_8hpp.js <==
var opencl_2matrix__operations_8hpp =
[
    [ "am", "opencl_2matrix__operations_8hpp.html#a9b46aa01fc67f7d7fbc95056a1f050c6", null ],
    [ "ambm", "opencl_2matrix__operations_8hpp.html#a7e146ec12db4a4ec440d6ca9b8e46b79", null ],
    [ "ambm_m", "opencl_2matrix__operations_8hpp.html#a9af548eaf628c556dcd90938a2e11528", null ],
    [ "bidiag_pack", "opencl_2matrix__operations_8hpp.html#a37fbfb949aae5a860d0308717e5b4ff5", null ],
    [ "bidiag_pack_svd", "opencl_2matrix__operations_8hpp.html#ae9e45a4202d75a28076b78d133ba9379", null ],
    [ "convert", "opencl_2matrix__operations_8hpp.html#a4e7dbe07ee5433438da8435cdb1a08ee", null ],
    [ "copy_vec", "opencl_2matrix__operations_8hpp.html#a5d5b4fe8827c4d4da9f2df19cf8ee971", null ],
    [ "element_op", "opencl_2matrix__operations_8hpp.html#ab4be1fe81c4ca79108c4db2d7b23ec2c", null ],
    [ "element_op", "opencl_2matrix__operations_8hpp.html#af9c69aabdf179456bdf212e4b34e8b9a", null ],
    [ "givens_next", "opencl_2matrix__operations_8hpp.html#aceca2a25a53f4b5c0dd836c8d024b170", null ],
    [ "house_update_A_left", "opencl_2matrix__operations_8hpp.html#a42d8cc5fddc8d8fe7819428f3570d8d7", null ],
    [ "house_update_A_right", "opencl_2matrix__operations_8hpp.html#aa37f02ed2a2f38dfea3abbfdeb5aab95", null ],
    [ "house_update_QL", "opencl_2matrix__operations_8hpp.html#a786d68766ad5e6b6fb239274efde0bf7", null ],
    [ "legacy_kernel_for_matrix", "opencl_2matrix__operations_8hpp.html#aa42a34c8e153495ac317c599824123d4", null ],
    [ "matrix_assign", "opencl_2matrix__operations_8hpp.html#a23eccb767cb852d60170403a671dd91b", null ],
    [ "matrix_column", "opencl_2matrix__operations_8hpp.html#a6860ecc724d3ef7a1ba363c379357abf", null ],
    [ "matrix_diag_from_vector", "opencl_2matrix__operations_8hpp.html#af22fcf715396698796b26f45bece179e", null ],
    [ "matrix_diag_to_vector", "opencl_2matrix__operations_8hpp.html#affe958b9b7dc9ad1986e2b2b2cdb757a", null ],
    [ "matrix_diagonal_assign", "opencl_2matrix__operations_8hpp.html#ab334de39e0a14eec29eef532cf625be9", null ],
    [ "matrix_row", "opencl_2matrix__operations_8hpp.html#ae3f1e3bfcb56428f4e73e030ebae7066", null ],
    [ "prod_impl", "opencl_2matrix__operations_8hpp.html#ac368f3b6c47973062b06a7b765ca4521", null ],
    [ "prod_impl", "opencl_2matrix__operations_8hpp.html#a16366a34aab924b279bcd2b4f403a159", null ],
    [ "scaled_rank_1_update", "opencl_2matrix__operations_8hpp.html#aa1db022508f1ca9f0a42269205ac2565", null ],
    [ "trans", "opencl_2matrix__operations_8hpp.html#a72bf0d80c0608b5645d06703c7807253", null ],
    [ "SVD_BIDIAG_PACK_KERNEL", "opencl_2matrix__operations_8hpp.html#a6c692160febc1bf0c8c1b3f14609843b", null ],
    [ "SVD_COPY_COL_KERNEL", "opencl_2matrix__operations_8hpp.html#a83f95bb0dba31593bfdea7d48825ef45", null ],
    [ "SVD_COPY_ROW_KERNEL", "opencl_2matrix__operations_8hpp.html#adf9d9e0232c7731006e942e6f1eb787c", null ],
    [ "SVD_GIVENS_NEXT_KERNEL", "opencl_2matrix__operations_8hpp.html#ae14982b121ba058e0cc0569b93f80646", null ],
    [ "SVD_HOUSEHOLDER_UPDATE_A_LEFT_KERNEL", "opencl_2matrix__operations_8hpp.html#a86b4bd11f0b1f0b701afa9448cbb865f", null ],
    [ "SVD_HOUSEHOLDER_UPDATE_A_RIGHT_KERNEL", "opencl_2matrix__operations_8hpp.html#a24049445243113b8aff433e4dd6d3c01", null ],
    [ "SVD_HOUSEHOLDER_UPDATE_QL_KERNEL", "opencl_2matrix__operations_8hpp.html#a656519064a982e5904b5a66b5e9c2785", null ]
];
